@@ -19,7 +19,9 @@ require 'spec_helper'
 describe 'tripleo::profile::base::gnocchi::api' do
   shared_examples_for 'tripleo::profile::base::gnocchi::api' do
     let(:pre_condition) do
-      "class { '::tripleo::profile::base::gnocchi': step => #{params[:step]}, }"
+      "
+        class { '::tripleo::profile::base::gnocchi': step => #{params[:step]}, }
+      "
     end
 
     context 'with step less than 3' do
@@ -73,7 +75,8 @@ describe 'tripleo::profile::base::gnocchi::api' do
         :step => 4,
         :gnocchi_backend => 'file',
         :gnocchi_redis_password => 'gnocchi',
-        :redis_vip => '127.0.0.1'
+        :redis_vip => '127.0.0.1',
+        :incoming_storage_driver => 'redis',
       } }
 
       it {
@@ -94,7 +97,9 @@ describe 'tripleo::profile::base::gnocchi::api' do
         :step => 4,
         :gnocchi_backend => 'rbd',
         :gnocchi_redis_password => 'gnocchi',
-        :redis_vip => '127.0.0.1'
+        :redis_vip => '127.0.0.1',
+        :gnocchi_rbd_client_name => 'openstack',
+        :incoming_storage_driver => 'redis',
       } }
 
       it {
@@ -107,6 +112,21 @@ describe 'tripleo::profile::base::gnocchi::api' do
           :redis_url => 'redis://:gnocchi@127.0.0.1:6379/'
         )
         is_expected.to contain_class('gnocchi::storage::ceph')
+        is_expected.to contain_exec('exec-setfacl-openstack-gnocchi')
+      }
+    end
+
+    context 'skip incoming storage in step 4' do
+      let(:params) { {
+        :step => 4,
+        :gnocchi_backend => 'rbd',
+        :gnocchi_redis_password => 'gnocchi',
+        :redis_vip => '127.0.0.1',
+        :incoming_storage_driver => '',
+      } }
+
+      it {
+        is_expected.not_to contain_class('gnocchi::storage::incoming::redis')
       }
     end
 
